@@ -28,6 +28,8 @@ parse_file <- function(path) {
   out$usage <- reconstruct(untag(rd$usage))
   out$desc <- gsub("$\n+|\n+^", "", reconstruct(untag(rd$description)))
   out$details <- reconstruct(untag(rd$details))
+  out$section <- paste(reconstruct(untag(rd$section[1])),
+                       reconstruct(untag(rd$section[-1])), sep = ': ')
   out$format <- reconstruct(untag(rd$format))
   out$value <- reconstruct(untag(rd$value))
   out$note <- reconstruct(untag(rd$note))
@@ -95,6 +97,7 @@ create_roxygen <- function(info, usage = FALSE) {
     comment_tag("@format", info$format),
     comment_tag("@return", info$value),
     comment_tag("@note", info$note),
+    comment_tag("@section", info$section),
     comment_tag("@author", info$author),
     comment_tag("@seealso", info$seealso),
     comment_tag("@references", info$references),
